responses

package
v0.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 24, 2018 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package responses provides extra utility functions for dealing with http responses.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Drain

func Drain(r *http.Response)

Drain the body of r, if it exists. Consuming the bytes of a response body is required for http clients to be able to re-use the underlying connection. Using the Drain method after

For more information on draining connections,

http://stackoverflow.com/questions/17948827/reusing-http-connections-in-golang

Types

This section is empty.

Jump to